@@ -1,7 +1,7 @@
 /* mpfr_cmp_d -- compare a floating-point number with a long double
 
-Copyright 2004, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
-Contributed by the AriC and Caramel projects, INRIA.
+Copyright 2004, 2006-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,10 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
+
+#include <float.h> /* needed so that MPFR_LDBL_MANT_DIG is correctly defined */
 
 #include "mpfr-impl.h"
 
@@ -27,12 +28,25 @@ mpfr_cmp_ld (mpfr_srcptr b, long double d)
 {
   mpfr_t tmp;
   int res;
+  MPFR_SAVE_EXPO_DECL (expo);
 
+  MPFR_SAVE_EXPO_MARK (expo);
+
+#if !HAVE_LDOUBLE_MAYBE_DOUBLE_DOUBLE
   mpfr_init2 (tmp, MPFR_LDBL_MANT_DIG);
+#else
+  /* since the smallest value is 2^(-1074) and the largest is < 2^1024,
+     every double-double is exactly representable with 1024 + 1074 bits */
+  mpfr_init2 (tmp, 1024 + 1074);
+#endif
   res = mpfr_set_ld (tmp, d, MPFR_RNDN);
   MPFR_ASSERTD (res == 0);
-  res = mpfr_cmp (b, tmp);
-  mpfr_clear (tmp);
 
+  MPFR_CLEAR_FLAGS ();
+  res = mpfr_cmp (b, tmp);
+  MPFR_SAVE_EXPO_UPDATE_FLAGS (expo, __gmpfr_flags);
+
+  mpfr_clear (tmp);
+  MPFR_SAVE_EXPO_FREE (expo);
   return res;
 }
