@@ -1,7 +1,7 @@
 /* auxiliary data to generate special IEEE floats (NaN, +Inf, -Inf)
 
-Copyright 1999-2017 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 1999-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 /* "double" NaN and infinities are written as explicit bytes to be sure of
    getting what we want, and to be sure of not depending on libm.
@@ -47,7 +46,7 @@ union dbl_bytes {
    quiet NaN (qNaN) or a signaling NaN (sNaN). For instance, HP PA-RISC
    is known to do the opposite way of the usual choice recommended in
    IEEE 754-2008; see:
-     http://grouper.ieee.org/groups/1788/email/msg03272.html
+     https://grouper.ieee.org/groups/1788/email/msg03272.html
 
    Moreover, the right choice is to generate a qNaN in particular because
    signaling NaNs are not supported by all compilers (note that the support
