@@ -1,7 +1,7 @@
 /* Memory allocation used during tests.
 
-Copyright 2001-2003, 2006-2019 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2001-2003, 2006-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,12 +16,13 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
-/* Note: this file comes from GMP's tests/memory.c */
+/* Note: this file originally came from GMP's tests/memory.c
+   (some features have been added). */
 
+#define MPFR_NEED_INTMAX_H
 #include "mpfr-test.h"
 
 /* Each block allocated is a separate malloc, for the benefit of a redzoning
@@ -68,8 +69,9 @@ mpfr_default_allocate (size_t size)
   if (MPFR_UNLIKELY (ret == NULL))
     {
       fprintf (stderr, "[MPFR] mpfr_default_allocate(): "
-               "can't allocate memory (size=%lu)\n",
-               (unsigned long) size);
+               "can't allocate memory (size=%" MPFR_INTMAX_FSPEC "u)\n",
+               (mpfr_uintmax_t) size);
+      fflush (NULL);
       abort ();
     }
   return ret;
@@ -83,8 +85,10 @@ mpfr_default_reallocate (void *oldptr, size_t old_size, size_t new_size)
   if (MPFR_UNLIKELY(ret == NULL))
     {
       fprintf (stderr, "[MPFR] mpfr_default_reallocate(): "
-               "can't reallocate memory (old_size=%lu new_size=%lu)\n",
-               (unsigned long) old_size, (unsigned long) new_size);
+               "can't reallocate memory (old_size=%" MPFR_INTMAX_FSPEC
+               "u new_size=%" MPFR_INTMAX_FSPEC "u)\n",
+               (mpfr_uintmax_t) old_size, (mpfr_uintmax_t) new_size);
+      fflush (NULL);
       abort ();
     }
   return ret;
@@ -129,8 +133,9 @@ tests_addsize (size_t size)
       /* The total size taken by MPFR on the heap is more than 4 MB:
          either a bug or a huge inefficiency. */
       fprintf (stderr, "[MPFR] tests_addsize(): "
-               "too much memory (%lu bytes)\n",
-              (unsigned long) tests_total_size);
+               "too much memory (%" MPFR_INTMAX_FSPEC "u bytes)\n",
+              (mpfr_uintmax_t) tests_total_size);
+      fflush (NULL);
       abort ();
     }
 }
@@ -146,6 +151,7 @@ tests_allocate (size_t size)
     {
       fprintf (stderr, "[MPFR] tests_allocate(): "
                "attempt to allocate 0 bytes\n");
+      fflush (NULL);
       abort ();
     }
 
@@ -163,6 +169,14 @@ tests_allocate (size_t size)
   return h->ptr;
 }
 
+/* Note: the double cast (mpfr_uintmax_t) (uintptr_t) below allows to avoid a
+   pointer-to-int-cast warning with GCC. The AC_TYPE_UINTPTR_T Autoconf macro
+   must be used to define uintptr_t if not available.
+   Note that pointers may be larger than uintmax_t, even in practice[*];
+   however, since this is just used in error messages, the loss of
+   information may be acceptable (but we should probably use %p).
+   [*] https://www.open-std.org/jtc1/sc22/wg14/www/docs/n2889.htm
+*/
 void *
 tests_reallocate (void *ptr, size_t old_size, size_t new_size)
 {
@@ -173,8 +187,9 @@ tests_reallocate (void *ptr, size_t old_size, size_t new_size)
   if (new_size == 0)
     {
       fprintf (stderr, "[MPFR] tests_reallocate(): "
-               "attempt to reallocate 0x%lX to 0 bytes\n",
-              (unsigned long) ptr);
+               "attempt to reallocate 0x%" MPFR_INTMAX_FSPEC "X to 0 bytes\n",
+               (mpfr_uintmax_t) (uintptr_t) ptr);
+      fflush (NULL);
       abort ();
     }
 
@@ -182,8 +197,9 @@ tests_reallocate (void *ptr, size_t old_size, size_t new_size)
   if (hp == NULL)
     {
       fprintf (stderr, "[MPFR] tests_reallocate(): "
-               "attempt to reallocate bad pointer 0x%lX\n",
-              (unsigned long) ptr);
+               "attempt to reallocate bad pointer 0x%" MPFR_INTMAX_FSPEC "X\n",
+              (mpfr_uintmax_t) (uintptr_t) ptr);
+      fflush (NULL);
       abort ();
     }
   h = *hp;
@@ -193,8 +209,10 @@ tests_reallocate (void *ptr, size_t old_size, size_t new_size)
       /* Note: we should use the standard %zu to print sizes, but
          this is not supported by old C implementations. */
       fprintf (stderr, "[MPFR] tests_reallocate(): "
-               "bad old size %lu, should be %lu\n",
-              (unsigned long) old_size, (unsigned long) h->size);
+               "bad old size %" MPFR_INTMAX_FSPEC
+               "u, should be %" MPFR_INTMAX_FSPEC "u\n",
+              (mpfr_uintmax_t) old_size, (mpfr_uintmax_t) h->size);
+      fflush (NULL);
       abort ();
     }
 
@@ -216,8 +234,9 @@ tests_free_find (void *ptr)
   if (hp == NULL)
     {
       fprintf (stderr, "[MPFR] tests_free(): "
-               "attempt to free bad pointer 0x%lX\n",
-              (unsigned long) ptr);
+               "attempt to free bad pointer 0x%" MPFR_INTMAX_FSPEC "X\n",
+              (mpfr_uintmax_t) (uintptr_t) ptr);
+      fflush (NULL);
       abort ();
     }
   return hp;
@@ -250,8 +269,10 @@ tests_free (void *ptr, size_t size)
     {
       /* Note: we should use the standard %zu to print sizes, but
          this is not supported by old C implementations. */
-      fprintf (stderr, "[MPFR] tests_free(): bad size %lu, should be %lu\n",
-              (unsigned long) size, (unsigned long) h->size);
+      fprintf (stderr, "[MPFR] tests_free(): bad size %"
+               MPFR_INTMAX_FSPEC "u, should be %" MPFR_INTMAX_FSPEC "u\n",
+              (mpfr_uintmax_t) size, (mpfr_uintmax_t) h->size);
+      fflush (NULL);
       abort ();
     }
 
@@ -293,6 +314,7 @@ tests_memory_end (void)
         count++;
 
       fprintf (stderr, "[MPFR]    %u blocks remaining\n", count);
+      fflush (NULL);
       abort ();
     }
 }
