@@ -1,7 +1,7 @@
 /* Test file for features related to exceptions.
 
-Copyright 2001-2018 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -44,7 +43,7 @@ check_default_rnd (void)
 {
   int r;
   mpfr_rnd_t t;
-  for(r = 0 ; r < MPFR_RND_MAX ; r++)
+  RND_LOOP (r)
     {
       mpfr_set_default_rounding_mode ((mpfr_rnd_t) r);
       t = (mpfr_get_default_rounding_mode) ();
@@ -103,10 +102,26 @@ static void
 check_get_prec (void)
 {
   mpfr_t x;
+  int i = 0;
 
   mpfr_init2 (x, 17);
-  if (mpfr_get_prec (x) != 17 || (mpfr_get_prec)(x) != 17)
+
+  if (mpfr_get_prec (x) != 17 || (mpfr_get_prec) (x) != 17)
     PRINT_ERROR ("mpfr_get_prec");
+
+#ifdef IGNORE_CPP_COMPAT
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wc++-compat"
+#endif
+
+  if (mpfr_get_prec ((i++, VOIDP_CAST(x))) != 17)
+    PRINT_ERROR ("mpfr_get_prec (2)");
+
+#ifdef IGNORE_CPP_COMPAT
+#pragma GCC diagnostic pop
+#endif
+
+  MPFR_ASSERTN (i == 1);
   mpfr_clear (x);
 }
 
@@ -152,13 +167,13 @@ check_flags (void)
 
   mpfr_set_ui (x, 1, MPFR_RNDN);
   (mpfr_clear_overflow)();
-  mpfr_mul_2exp (x, x, 1024, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1024, MPFR_RNDN);
   if (!(mpfr_overflow_p)())
     PRINT_ERROR ("ERROR: No overflow detected!\n");
 
   (mpfr_clear_underflow)();
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_div_2exp (x, x, 1025, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1025, MPFR_RNDN);
   if (!(mpfr_underflow_p)())
     PRINT_ERROR ("ERROR: No underflow detected!\n");
 
@@ -176,7 +191,7 @@ check_flags (void)
 
   (mpfr_clear_erangeflag) ();
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 1024, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1024, MPFR_RNDN);
   mpfr_get_ui (x, MPFR_RNDN);
   if (!(mpfr_erangeflag_p)())
     PRINT_ERROR ("ERROR: No erange flag!\n");
@@ -203,7 +218,7 @@ test_set_underflow (void)
   r[1] = r[3] = zero;       /* RNDZ, RNDD */
   for (s = 1; s > 0; s = -1)
     {
-      for (i = 0; i < MPFR_RND_MAX ; i++)
+      RND_LOOP (i)
         {
           int j;
           int inex;
@@ -263,7 +278,7 @@ test_set_overflow (void)
   r[1] = r[3] = max;        /* RNDZ, RNDD */
   for (s = 1; s > 0; s = -1)
     {
-      for (i = 0; i < MPFR_RND_MAX ; i++)
+      RND_LOOP (i)
         {
           int j;
           int inex;
@@ -388,7 +403,7 @@ check_groups (void)
       MPFR_ASSERTN ((mpfr_flags_save) () == f1);
       MPFR_ASSERTN (__gmpfr_flags == f1);
       mask = randlimb () & MPFR_FLAGS_ALL;
-      if (randlimb () & 1)
+      if (RAND_BOOL ())
         mpfr_flags_set (mask);
       else
         (mpfr_flags_set) (mask);
@@ -404,7 +419,7 @@ check_groups (void)
 
       f2 = __gmpfr_flags;
       mask = randlimb () & MPFR_FLAGS_ALL;
-      if (randlimb () & 1)
+      if (RAND_BOOL ())
         mpfr_flags_clear (mask);
       else
         (mpfr_flags_clear) (mask);
@@ -419,8 +434,7 @@ check_groups (void)
           }
 
       mask = randlimb () & MPFR_FLAGS_ALL;
-      f2 = (randlimb () & 1) ?
-        mpfr_flags_test (mask) : (mpfr_flags_test) (mask);
+      f2 = RAND_BOOL () ? mpfr_flags_test (mask) : (mpfr_flags_test) (mask);
       for (j = 1; j <= MPFR_FLAGS_ALL; j <<= 1)
         if ((f2 & j) != ((mask & j) != 0 ? (__gmpfr_flags & j) : 0))
           {
@@ -432,7 +446,7 @@ check_groups (void)
           }
 
       f2 = __gmpfr_flags;
-      if (randlimb () & 1)
+      if (RAND_BOOL ())
         mpfr_flags_restore (f1, mask);
       else
         (mpfr_flags_restore) (f1, mask);
@@ -473,7 +487,7 @@ main (int argc, char *argv[])
     }
 
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 1024, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1024, MPFR_RNDN);
   mpfr_set_double_range ();
   mpfr_check_range (x, 0, MPFR_RNDN);
   if (!mpfr_inf_p (x) || (mpfr_sgn(x) <= 0))
@@ -484,7 +498,7 @@ main (int argc, char *argv[])
 
   set_emax (1025);
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 1024, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1024, MPFR_RNDN);
   mpfr_set_double_range ();
   mpfr_check_range (x, 0, MPFR_RNDD);
   if (!mpfr_number_p (x))
@@ -494,7 +508,7 @@ main (int argc, char *argv[])
     }
 
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 1023, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1023, MPFR_RNDN);
   mpfr_add (x, x, x, MPFR_RNDN);
   if (!mpfr_inf_p (x) || (mpfr_sgn(x) <= 0))
     {
@@ -505,7 +519,7 @@ main (int argc, char *argv[])
     }
 
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 1023, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 1023, MPFR_RNDN);
   mpfr_add (x, x, x, MPFR_RNDD);
   if (!mpfr_number_p (x))
     {
@@ -515,7 +529,7 @@ main (int argc, char *argv[])
     }
 
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_div_2exp (x, x, 1022, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1022, MPFR_RNDN);
   mpfr_set_str_binary (y, "1.1e-1022"); /* y = 3/2*x */
   mpfr_sub (y, y, x, MPFR_RNDZ);
   if (mpfr_cmp_ui (y, 0))
@@ -528,7 +542,7 @@ main (int argc, char *argv[])
 
   set_emin (-1026);
   mpfr_set_ui (x, 1, MPFR_RNDN);
-  mpfr_div_2exp (x, x, 1025, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1025, MPFR_RNDN);
   mpfr_set_double_range ();
   mpfr_check_range (x, 0, MPFR_RNDN);
   if (!MPFR_IS_ZERO (x) )
