@@ -1,7 +1,7 @@
 /* Test file for mpfr_ui_div.
 
-Copyright 2000-2017 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2000-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,12 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
-
-#include <stdio.h>
-#include <stdlib.h>
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -58,7 +54,7 @@ check_inexact (void)
   mpfr_init (y);
   mpfr_init (z);
 
-  for (px = 2; px < 300; px++)
+  for (px = MPFR_PREC_MIN; px < 300; px++)
     {
       mpfr_set_prec (x, px);
       do
@@ -67,11 +63,11 @@ check_inexact (void)
         }
       while (mpfr_cmp_ui (x, 0) == 0);
       u = randlimb ();
-      for (py = 2; py < 300; py++)
+      for (py = MPFR_PREC_MIN; py < 300; py++)
         {
           mpfr_set_prec (y, py);
           mpfr_set_prec (z, py + px);
-          for (rnd = 0; rnd < MPFR_RND_MAX; rnd++)
+          RND_LOOP (rnd)
             {
               inexact = mpfr_ui_div (y, u, x, (mpfr_rnd_t) rnd);
               if (mpfr_mul (z, y, x, (mpfr_rnd_t) rnd))
@@ -80,7 +76,7 @@ check_inexact (void)
                   exit (1);
                 }
               cmp = mpfr_cmp_ui (z, u);
-              if (! SAME_SIGN (inexact, cmp))
+              if (rnd != MPFR_RNDF && ! SAME_SIGN (inexact, cmp))
                 {
                   printf ("Wrong inexact flag for u=%lu, rnd=%s\n",
                           u, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
@@ -107,13 +103,12 @@ check_special (void)
   mpfr_init2 (d, 100L);
   mpfr_init2 (q, 100L);
 
-  /* 1/+inf == 0 */
+  /* 1/+inf == +0 */
   MPFR_SET_INF (d);
   MPFR_SET_POS (d);
   mpfr_clear_flags ();
   MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
-  MPFR_ASSERTN (mpfr_number_p (q));
-  MPFR_ASSERTN (mpfr_sgn (q) == 0);
+  MPFR_ASSERTN (MPFR_IS_ZERO (q) && MPFR_IS_POS (q));
   MPFR_ASSERTN (__gmpfr_flags == 0);
 
   /* 1/-inf == -0 */
@@ -121,8 +116,7 @@ check_special (void)
   MPFR_SET_NEG (d);
   mpfr_clear_flags ();
   MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
-  MPFR_ASSERTN (mpfr_number_p (q));
-  MPFR_ASSERTN (mpfr_sgn (q) == 0);
+  MPFR_ASSERTN (MPFR_IS_ZERO (q) && MPFR_IS_NEG (q));
   MPFR_ASSERTN (__gmpfr_flags == 0);
 
   /* 1/nan == nan */
@@ -158,14 +152,14 @@ check_special (void)
   mpfr_set_ui (d, 1L, MPFR_RNDN);
   mpfr_clear_flags ();
   MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, MPFR_RNDZ) == 0); /* exact */
-  MPFR_ASSERTN (mpfr_cmp_ui (q, 0) == 0 && MPFR_IS_POS (q));
+  MPFR_ASSERTN (MPFR_IS_ZERO (q) && MPFR_IS_POS (q));
   MPFR_ASSERTN (__gmpfr_flags == 0);
 
   /* 0/-1 = -0 */
   mpfr_set_si (d, -1, MPFR_RNDN);
   mpfr_clear_flags ();
   MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, MPFR_RNDZ) == 0); /* exact */
-  MPFR_ASSERTN (mpfr_cmp_ui (q, 0) == 0 && MPFR_IS_NEG (q));
+  MPFR_ASSERTN (MPFR_IS_ZERO (q) && MPFR_IS_NEG (q));
   MPFR_ASSERTN (__gmpfr_flags == 0);
 
   mpfr_clear (d);
@@ -184,7 +178,7 @@ check_overflow (void)
   mpfr_exp_t emin, emax;
   mpfr_t x, y1, y2;
   int inex1, inex2, rnd_mode;
-  unsigned int flags1, flags2;
+  mpfr_flags_t flags1, flags2;
 
   emin = mpfr_get_emin ();
   emax = mpfr_get_emax ();
@@ -247,7 +241,7 @@ main (int argc, char *argv[])
         "-6.8938315017943889615e-297");
   check_overflow ();
 
-  test_generic (2, 1000, 100);
+  test_generic (MPFR_PREC_MIN, 1000, 100);
 
   /* inv is for 1/x */
   data_check ("data/inv", mpfr_inv, "mpfr_ui_div(1,x)");
